--  Telemetry widget: 
--  ###################################################################################
--
--  version 1  29.05.2023
--  by ChrisOHara
--  OpenTX version 2.3.15
--  for Horus (but only tested in companion, may run on similar radios as well)
--  This Software is free, no guarantee, usage at one's own risk
--
--  Displays telemetry value altitude and announces new values in steps of 10 meters (or ft)
--  uses logical switch 60  to switch on/off announcement
--
--########################################################################################################

local my_steps_meter = 10;   -- steps in meter
local my_steps_feet = 30;    -- steps in feet
local my_steps;

local ls60_Id;
local altId;
local announcedAltitude;
local my_Alt_unit;
local my_Alt_unitName = " ";


-- ############################# init function ##################
local function AltAno_init()

      ls60_Id = getFieldInfo("ls60") and getFieldInfo("ls60").id or nil ;
      altId = getFieldInfo("Alt") and getFieldInfo("Alt").id or nil;

      for i = 0, 39 do                           -- looking for Alt sensors unit
         my_sensor = model.getSensor(i);
         if my_sensor.name == "Alt" then
            my_Alt_unit = my_sensor.unit;
            if my_Alt_unit ==  9 then
                my_Alt_unitName = "m" ;
                my_steps = my_steps_meter;
              end;
            if my_Alt_unit == 10 then
                my_Alt_unitName = "ft" ;
                my_steps = my_steps_feet;
              end;
          end;
      end;
      my_sensor = nil;

      announcedAltitude = my_steps * math.floor ( getValue(altId) / my_steps );

      return 
end


-- ########################### background function #############################
local function AltAno_bg()

        local newAltitude = math.floor ( getValue(altId));
	local difference = math.abs ( newAltitude - announcedAltitude );
        if difference >= my_steps then
             announcedAltitude = my_steps * math.floor ( (newAltitude / my_steps) + 0.5 ) ;
             if ((getValue(ls60_Id) > 1000)) then playNumber(announcedAltitude, my_Alt_unit, PREC0 ); end;       
          end;

	return;
end


-- ############################### run function #####################
local function AltAno_run()

        lcd.clear();
        local realAltitude = math.floor ( getValue(altId) + 0.5 );

	lcd.drawText (0,0,"Altitude", MIDSIZE);
      	lcd.drawText (30,30,""..realAltitude.." "..my_Alt_unitName, DBLSIZE);

	return 0;
end

return { name = "AltAno", init=AltAno_init, background= AltAno_bg, run=AltAno_run}

