--  Telemetry widget: 
--  ###################################################################################
--
--  version 1  29.05.2023
--  by ChrisOHara
--  OpenTX version 2.3.15
--  for Horus (but only tested in companion, may run on similar radios as well)
--  This Software is free, no guarantee, usage at one's own risk
--
--  Displays telemetry value altitude and announces new values in steps of 10 meters (or ft)
--
--
--########################################################################################################

local my_steps_meter = 10;   -- steps in meter
local my_steps_feet = 30;    -- steps in feet
local my_steps;

local ls60_Id;
local altId;
local announcedAltitude;
local my_Alt_unit;
local my_Alt_unitName = " ";

local my_xy = { xx={}, yy={}};

local options = {
	{ "Restore", BOOL, 0},
	{ "Text", COLOR, BLACK},
	{ "Warning", COLOR, YELLOW} }


-- ############################# init function ##################
local function AltAno_create(zone, options)

      ls60_Id = getFieldInfo("ls60") and getFieldInfo("ls60").id or nil ;
      altId = getFieldInfo("Alt") and getFieldInfo("Alt").id or nil;

      for i = 0, 39 do                           -- looking for Alt sensors unit
         my_sensor = model.getSensor(i);
         if my_sensor.name == "Alt" then
            my_Alt_unit = my_sensor.unit;
            if my_Alt_unit ==  9 then
                my_Alt_unitName = "m" ;
                my_steps = my_steps_meter;
              end;
            if my_Alt_unit == 10 then
                my_Alt_unitName = "ft" ;
                my_steps = my_steps_feet;
              end;
          end;
         end;
      my_sensor = nil;

      announcedAltitude = my_steps * math.floor ( getValue(altId) / my_steps );


-- calcutating coordinates for display
	local AltAnoZone = { zone = zone, options = options } ;
	my_xy.xx[0] = AltAnoZone.zone.x + 0;	my_xy.yy[0] = AltAnoZone.zone.y + 0
	my_xy.xx[1] = AltAnoZone.zone.x + 5;	my_xy.yy[1] = AltAnoZone.zone.y + 20	
	  my_xy.xx[2] = AltAnoZone.zone.x + 100;	my_xy.yy[2] = AltAnoZone.zone.y + 20
	my_xy.xx[3] = AltAnoZone.zone.x + 5;	my_xy.yy[3] = AltAnoZone.zone.y + 50
	  my_xy.xx[4] = AltAnoZone.zone.x + 100;	my_xy.yy[4] = AltAnoZone.zone.y + 50
	return AltAnoZone
end

-- #################### This function allow updates when you change widgets settings #####################
local function AltAno_update(AltAnoZone, options)
	AltAnoZone.options = options
	return;
end

-- ########################### background function #############################
local function AltAno_bg(AltAnoZone)

        local newAltitude = math.floor ( getValue(altId));
	local difference = math.abs ( newAltitude - announcedAltitude );
        if difference >= my_steps then
             announcedAltitude = my_steps * math.floor ( (newAltitude / my_steps) + 0.5 ) ;
             if ((getValue(ls60_Id) > 1000)) then playNumber(announcedAltitude, my_Alt_unit, PREC0 ); end;       
          end;

	return;
end


-- ############################### run function #####################
local function AltAno_refresh(AltAnoZone)

        local realAltitude = math.floor ( getValue(altId) + 0.5 );

	AltAno_bg(AltAnoZone);

	lcd.drawText (my_xy.xx[0],my_xy.yy[0],"Altitude", MIDSIZE);
      	lcd.drawText (my_xy.xx[1],my_xy.yy[1],""..realAltitude.." "..my_Alt_unitName, DBLSIZE);

	return 0;
end

return { name = "AltAno", options=options, create=AltAno_create, update=AltAno_update, background= AltAno_bg, refresh=AltAno_refresh}

